@@ -8,7 +8,7 @@ from pathlib import Path
 # DjangoTemplateConverter
 
 requiredAll = ['css', 'png', 'jpg', 'json','ico']
-requiredOnly = ['css', 'png', 'jpg', 'json','ico']
+requiredOnly = ['css']
 
 def main():
     parser = argparse.ArgumentParser()
